.. pyrwt documentation master file, created by
   sphinx-quickstart on Fri Sep 07 22:43:43 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyrwt's documentation!
=================================

.. automodule:: rwt.__init__
    :members:
    :undoc-members:
    :show-inheritance:

Contents:

.. toctree::
   :maxdepth: 2

   install
   tutorial
   wavelets
   reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Meta information
================

.. toctree::
   :maxdepth: 2

   license
